@@ -19,7 +19,19 @@ class Thing:
         """ end position of the thing """
         return self._end_position
 
-    def __init__(self, position=None):
+    def reposition(self, pos):
+        """
+        Reposition the thing
+        In things like "Line" additional logic is needed to reposition
+
+        :param pos: new position
+        :return:
+        """
+
+        self._position = pos
+        self._end_position = None
+
+    def __init__(self, position):
         """
         Create a thing
         :param position: build position
@@ -30,10 +42,10 @@ class Thing:
         if position:
             self._position = mcpi.vec3.Vec3(position.x, position.y, position.z)
 
-        # Add then thing built to the creation thing
-        from .creation import Creation
+        # Add then thing built to the scene
+        from .scene import Scene
 
-        Creation.add(self)
+        Scene.add(self)
 
     def build(self):
         """
